@@ -5,7 +5,7 @@ use Moose;
 use Config::General;
 use Data::Dumper;
 
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 has file => (
     is       => 'rw',
@@ -42,8 +42,8 @@ sub _setup {
         $self->_add_user(
             $username => {
                 $password ? ( password => $password ) : (),
-                $allow ? ( allow => [ split( / /, $allow ) ] ) : (),
-                roles => [ split( / /, $roles ) ]
+                $allow ? ( allow => [ split(' ' , $allow ) ] ) : (),
+                roles => [ split(' ', $roles ) ]
             }
         );
     }
@@ -57,7 +57,21 @@ sub auth {
     return 0 unless $username and $password;
     my $user = $self->_find_user($username) or return 0;
     my $mem_password = $user->{password};
-    return $mem_password eq $password ? 1 : 0;
+    return $mem_password eq $password ? $username : 0;
+}
+
+
+sub auth_ip {
+    my ( $self, $ip ) = @_;
+    return 0 unless $ip;
+    my %users = $self->_all_users;
+    foreach my $user ( keys %users ) {
+        my ( @roles, @allow );
+        @allow = @{ $users{$user}{allow} } if defined( $users{$user}{allow} );
+        @roles = @{ $users{$user}{roles} } if defined( $users{$user}{roles} );
+        return $user if grep( /$ip|all/, @allow );
+    }
+    return 0;
 }
 
 
@@ -107,7 +121,7 @@ ReRe::User
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 METHODS
 
@@ -117,6 +131,12 @@ Authentication
 
 (username, password)
 
+=head2 auth_ip
+
+Authentication by IP
+
+($ip)
+
 =head2 has_role
 
 Autorization
